@@ -50,13 +50,16 @@ typedef struct
         guint            lock_enabled : 1;		/* whether to lock when active */
         guint            logout_enabled : 1;	/* Whether to offer the logout option */
         guint            user_switch_enabled : 1;	/* Whether to offer the user switch option */
+        guint            keyboard_enabled : 1;	/* Whether to try to embed a keyboard */
 
+        guint            power_timeout;	       	/* how much idle time before power management */
         guint            timeout;	       	/* how much idle time before activation */
         guint            lock_timeout;		/* how long after activation locking starts */
         guint            logout_timeout;	/* how long until the logout option appears */
         guint            cycle;			/* how long each theme should run */
 
         char            *logout_command;        /* command to use to logout */
+        char            *keyboard_command;      /* command to use to embed a keyboard */
 
         GSList          *themes;       		/* the screensaver themes to run */
         GSSaverMode      mode;			/* theme selection mode */
